/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.artifactdatabase.objects.map;

import java.util.Collection;

/**
 * The default implementation of <code>MapService</code>.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public class DefaultMapService implements MapService {

    /**
     * The id of this mapservice.
     */
    private String id = null;

    /**
     * The layer which are provided by this mapservice.
     */
    private Collection<Layer> layer = null;

    /**
     * The type of this mapservice.
     */
    private String type = null;

    /**
     * The URl of this mapservice.
     */
    private String url = null;
    
    /**
     * The Bbox which surrounds the data of the Mapservice
     */
    private String bbox = null;
    
    /**
     * The time until the server will provide the data.
     */
    private String ttl = null;

    /**
     * Constructor
     * 
     * @param id  the id of this mapservice
     * @param layer the layer which are provided by this mapservice
     * @param type the type of this mapservice
     * @param url the URl of this mapservice
     */
    public DefaultMapService(String id, Collection<Layer> layer,
                             String type, String url) {
        super();
        this.id = id;
        this.layer = layer;
        this.type = type;
        this.url = url;
    }
    
    /**
     * Constructor
     * 
     * @param id  the id of this mapservice
     * @param layer the layer which are provided by this mapservice
     * @param type the type of this mapservice
     * @param url the URl of this mapservice
     * @param bbox the Bbox which surrounds the data of the Mapservice
     * @param ttl the time until the server will provide the data.
     */
    public DefaultMapService(String id, Collection<Layer> layer,
                             String type, String url, String bbox, String ttl) {
        this(id,layer,type,url);
        this.bbox = bbox;
        this.ttl = ttl;
    }


    public String getID() {
        return this.id;
    }


    public Collection<Layer> getLayer() {
        return this.layer;
    }


    public String getType() {
        return this.type;
    }


    public String getURL() {
        return this.url;
    }
    
    public String getBBoxValue() {
        return this.bbox;
    }
    public String getTtl() {
        return this.ttl;
}
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
